Class: Low::Events::RenderEvent
- Inherits:
-
Data
- Object
- Data
- Low::Events::RenderEvent
- Defined in:
- lib/events/render_event.rb
Instance Attribute Summary collapse
-
#action ⇒ Object
readonly
Returns the value of attribute action.
-
#props ⇒ Object
readonly
Returns the value of attribute props.
Instance Method Summary collapse
-
#initialize(action: :render, props: {}) ⇒ RenderEvent
constructor
TODO: Duplicate props when used in a parallelized situation (antlers: “<{ :parallelize }>”).
Constructor Details
#initialize(action: :render, props: {}) ⇒ RenderEvent
TODO: Duplicate props when used in a parallelized situation (antlers: “<{ :parallelize }>”)
7 8 9 |
# File 'lib/events/render_event.rb', line 7 def initialize(action: :render, props: {}) super end |
Instance Attribute Details
#action ⇒ Object (readonly)
Returns the value of attribute action
5 6 7 |
# File 'lib/events/render_event.rb', line 5 def action @action end |
#props ⇒ Object (readonly)
Returns the value of attribute props
5 6 7 |
# File 'lib/events/render_event.rb', line 5 def props @props end |